####################
Models API Reference
####################

.. automodule:: topgg.types
    :members:

.. autoclass:: topgg.types.DataDict
    :members:
    :inherited-members:

.. autoclass:: topgg.types.BotData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.BotStatsData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.BriefUserData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.UserData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.SocialData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.VoteDataDict
    :members:
    :show-inheritance:
    
.. autoclass:: topgg.types.BotVoteData
    :members:
    :show-inheritance:

.. autoclass:: topgg.types.GuildVoteData
    :members:
    :show-inheritance: